Public Class MainForm
    '1.1 TIFF tag's definitions.
    '==========================================================================================
    Const AP_TIFF_COMPRESSION_NONE = 0      'No compression.
    Const AP_TIFF_COMPRESSION_LZW = 1       '1,4,8,24bits(default 4,8,24bits)
    Const AP_TIFF_COMPRESSION_JPEG = 2      'Grayscale 8bits,24bits
    Const AP_TIFF_COMPRESSION_PACKBITS = 3  '4,8,24bits
    Const AP_TIFF_COMPRESSION_CCITTG4 = 4   '1bit(default 1bit)
    Const AP_TIFF_COMPRESSION_CCITTG3 = 5   '1bit
    Const AP_TIFF_COMPRESSION_RLE = 6       '1bit
    '==========================================================================================

    '1.2 Return code's definitions.
    '==========================================================================================
    Const RTN_OK = 1           'Successful operation.
    Const ERR_UNKNOWN = -99    'Unknown system error.

    Const ERR_OVER_MAXTHREADS = -1     'Over the limit amount of threads
    Const ERR_FILE_UNEXIST = -2        'Source PDF file unexist.
    Const ERR_FILE_DAMAGED = -3        'Source PDF file is damaged.
    Const ERR_FILE_RESTRICTED = -4     'Source PDF file is restricted.

    Const ERR_INVALID_PAGE = -5      'The PDF page is invalid.
    Const ERR_CONVERT_FAILURE = -8   'Conversion failure.
    Const ERR_INVALID_STREAM = -9    'Invalid memory stream address.
    Const ERR_INVALID_HANDLE = -10   'The handle of conversion object is invalid.
    '==========================================================================================

    '1.3 Windows API definitions.
    '==========================================================================================
    Private Const OFS_MAXPATHNAME = 128

    Private Declare Function GetTickCount Lib "kernel32" () As Integer
    Private Declare Function GetCurrentProcess Lib "kernel32" () As Integer
    Private Declare Function ReadProcessMemory Lib "kernel32" (ByVal hProcess As Integer, ByVal lpBaseAddress As Integer, ByVal lpBuffer() As Byte, ByVal nSize As Integer, ByRef lpNumberOfBytesWritten As Integer) As Integer
    '==========================================================================================

    'Demo1 - To convert all pages of the pdf document.
    Private Sub btnDemo1_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnDemo1.Click
        Dim m_AxPdf2Tiff As New AP_PDF2TIFF.AxPdf2Tiff
        Dim nHandle As Integer
        Dim sFileName As String
        Dim iStartTick, iEndTick As Integer
        Dim iPageNo, iPageCount As Integer

        sFileName = "sample.pdf"
        iStartTick = GetTickCount

        'Open pdf document and creating a converter.
        nHandle = m_AxPdf2Tiff.apOpen(sFileName, "", "")
        Select Case nHandle
            Case ERR_OVER_MAXTHREADS
                MsgBox("Over the limit amount of threads,please waiting!")
                Exit Sub
            Case ERR_FILE_UNEXIST
                MsgBox("Source pdf file unexist!")
                Exit Sub
            Case ERR_FILE_DAMAGED
                MsgBox("Source pdf file damaged!")
                Exit Sub
            Case ERR_FILE_RESTRICTED
                MsgBox("Source pdf file restricted!")
                Exit Sub
        End Select

        'Setting proerties.
        m_AxPdf2Tiff.sOutDirectory = "./demo1"
        m_AxPdf2Tiff.iMultiPages = 1  'To generate multipages tiff.
        m_AxPdf2Tiff.iCompression = AP_TIFF_COMPRESSION_LZW
        m_AxPdf2Tiff.iXDPI = 130
        m_AxPdf2Tiff.iYDPI = 130

        'To convert all pages of the pdf document.
        iPageCount = m_AxPdf2Tiff.apGetPageCount(nHandle)
        For iPageNo = 1 To iPageCount
            m_AxPdf2Tiff.apConvertPage(nHandle, iPageNo)

            'Setting conversion's progress.
            m_ProgressBar.Value = Math.Round((iPageNo * 1.0#) / iPageCount * 100)
        Next

        'Close pdf document and destory the converter.
        m_AxPdf2Tiff.apClose(nHandle)

        'To count conversion's time(ms).
        iEndTick = GetTickCount()
        MsgBox("Conversion successful,it passed " + CStr(iEndTick - iStartTick) + "ms!")
    End Sub

    Private Sub btnDemo2_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnDemo2.Click
        Dim m_AxPdf2Tiff As New AP_PDF2TIFF.AxPdf2Tiff
        Dim nHandle As Integer
        Dim sFileName, sImgFile As String
        Dim iStartTick, iEndTick, iPageCount, iPos As Integer
        Dim m_Pages(6) As Integer
        m_Pages(0) = 1
        m_Pages(1) = 3
        m_Pages(2) = 6
        m_Pages(3) = 8
        m_Pages(4) = 9
        m_Pages(5) = 11

        sFileName = "sample.pdf"
        iStartTick = GetTickCount()

        'Open pdf file and creating a converter.
        nHandle = m_AxPdf2Tiff.apOpen("sample.pdf", "", "")
        Select Case nHandle
            Case ERR_OVER_MAXTHREADS
                MsgBox("Over the limit amount of threads,please waiting!")
                Exit Sub
            Case ERR_FILE_UNEXIST
                MsgBox("Source pdf file unexist!")
                Exit Sub
            Case ERR_FILE_DAMAGED
                MsgBox("Source pdf file damaged!")
                Exit Sub
            Case ERR_FILE_RESTRICTED
                MsgBox("Source pdf file restricted!")
                Exit Sub
        End Select

        'Setting proerties.
        m_AxPdf2Tiff.iCompression = AP_TIFF_COMPRESSION_LZW
        m_AxPdf2Tiff.iXDPI = 110
        m_AxPdf2Tiff.iYDPI = 110
        m_AxPdf2Tiff.iXDimensions = 995
        m_AxPdf2Tiff.iYDimensions = 1287

        System.IO.Directory.CreateDirectory("./demo2")
        iPageCount = UBound(m_Pages)
        For iPos = 0 To iPageCount - 1
            'You can save the image stream to database, to file, or to others, etc.
            m_AxPdf2Tiff.apConvertPageToStream(nHandle, m_Pages(iPos))

            'Here,it saves the memory stream of the image to bytes buffer
            Dim bBuffer(m_AxPdf2Tiff.iStreamSize) As Byte
            Dim nBytesRead As Integer
            Dim iCurrPID = GetCurrentProcess()  'Current Process ID.
            ReadProcessMemory(iCurrPID, m_AxPdf2Tiff.iStreamHandle, bBuffer, m_AxPdf2Tiff.iStreamSize, nBytesRead)

            'Here,it saves the buffer to file.
            If nBytesRead > 0 Then
                sImgFile = "./demo2/myimg_" + CStr(m_Pages(iPos)) + ".tif"

                Dim fileStream As System.IO.FileStream
                fileStream = New System.IO.FileStream(sImgFile, System.IO.FileMode.OpenOrCreate, System.IO.FileAccess.Write)
                fileStream.Write(bBuffer, 0, nBytesRead)
                fileStream.Close()
            End If

            'Setting conversion's progress.
            m_ProgressBar.Value = Math.Round(((iPos + 1) * 1.0#) / iPageCount * 100)
        Next

        'Close pdf document and destory the converter.
        m_AxPdf2Tiff.apClose(nHandle)

        'To count conversion's time(ms).
        iEndTick = GetTickCount()
        MsgBox("Conversion successful,it passed " + CStr(iEndTick - iStartTick) + "ms!")
    End Sub
End Class
